# tangram_globe

The `tangram_globe` plugin adds a toggle to switch in the top navigatio bar to switch between Mercator and globe view


## About Tangram

`tangram_globe` is a plugin for `tangram`, an open framework for modular, real-time air traffic management research.

- Documentation: <https://mode-s.org/tangram/>
- Repository: <https://github.com/open-aviation/tangram>

Installation:

```sh
# cli via uv
uv tool install --with tangram-globe tangram-core
# with pip
pip install tangram-core tangram-globe
```
